==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_functions/mp3026_001/MP3026_SyncEquipLinearRef_001.java <==

package net.datastream.schemas.mp_functions.mp3026_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.equiplinearref_001.EquipLinearRef;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/EquipLinearRef_001}EquipLinearRef"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="EquipLinearRef" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirm_different_lrfdesc" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirm_remove_setid" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirm_recreate_repeatSet" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipLinearRef"
})
@XmlRootElement(name = "MP3026_SyncEquipLinearRef_001")
public class MP3026_SyncEquipLinearRef_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "EquipLinearRef", namespace = "http://schemas.datastream.net/MP_entities/EquipLinearRef_001", required = true)
    protected EquipLinearRef equipLinearRef;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_different_lrfdesc")
    protected String confirm_Different_Lrfdesc;
    @XmlAttribute(name = "confirm_remove_setid")
    protected String confirm_Remove_Setid;
    @XmlAttribute(name = "confirm_recreate_repeatSet")
    protected String confirm_Recreate_RepeatSet;

    /**
     * Obtient la valeur de la propriété equipLinearRef.
     * 
     * @return
     *     possible object is
     *     {@link EquipLinearRef }
     *     
     */
    public EquipLinearRef getEquipLinearRef() {
        return equipLinearRef;
    }

    /**
     * Définit la valeur de la propriété equipLinearRef.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipLinearRef }
     *     
     */
    public void setEquipLinearRef(EquipLinearRef value) {
        this.equipLinearRef = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.EQUIP_LINEAR_REF;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Different_Lrfdesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Different_Lrfdesc() {
        if (confirm_Different_Lrfdesc == null) {
            return "prompt";
        } else {
            return confirm_Different_Lrfdesc;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Different_Lrfdesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Different_Lrfdesc(String value) {
        this.confirm_Different_Lrfdesc = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Remove_Setid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Remove_Setid() {
        if (confirm_Remove_Setid == null) {
            return "prompt";
        } else {
            return confirm_Remove_Setid;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Remove_Setid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Remove_Setid(String value) {
        this.confirm_Remove_Setid = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Recreate_RepeatSet.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Recreate_RepeatSet() {
        if (confirm_Recreate_RepeatSet == null) {
            return "prompt";
        } else {
            return confirm_Recreate_RepeatSet;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Recreate_RepeatSet.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Recreate_RepeatSet(String value) {
        this.confirm_Recreate_RepeatSet = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/mp3026_001/MP3026_SyncEquipLinearRef_001.java <==

package net.datastream.schemas.mp_functions.mp3026_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.equiplinearref_001.EquipLinearRef;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/EquipLinearRef_001}EquipLinearRef"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="EquipLinearRef" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirm_different_lrfdesc" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirm_remove_setid" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="confirm_recreate_repeatSet" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipLinearRef"
})
@XmlRootElement(name = "MP3026_SyncEquipLinearRef_001")
public class MP3026_SyncEquipLinearRef_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "EquipLinearRef", namespace = "http://schemas.datastream.net/MP_entities/EquipLinearRef_001", required = true)
    protected EquipLinearRef equipLinearRef;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_different_lrfdesc")
    protected String confirm_Different_Lrfdesc;
    @XmlAttribute(name = "confirm_remove_setid")
    protected String confirm_Remove_Setid;
    @XmlAttribute(name = "confirm_recreate_repeatSet")
    protected String confirm_Recreate_RepeatSet;

    /**
     * Gets the value of the equipLinearRef property.
     * 
     * @return
     *     possible object is
     *     {@link EquipLinearRef }
     *     
     */
    public EquipLinearRef getEquipLinearRef() {
        return equipLinearRef;
    }

    /**
     * Sets the value of the equipLinearRef property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipLinearRef }
     *     
     */
    public void setEquipLinearRef(EquipLinearRef value) {
        this.equipLinearRef = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.EQUIP_LINEAR_REF;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the confirm_Different_Lrfdesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Different_Lrfdesc() {
        if (confirm_Different_Lrfdesc == null) {
            return "prompt";
        } else {
            return confirm_Different_Lrfdesc;
        }
    }

    /**
     * Sets the value of the confirm_Different_Lrfdesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Different_Lrfdesc(String value) {
        this.confirm_Different_Lrfdesc = value;
    }

    /**
     * Gets the value of the confirm_Remove_Setid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Remove_Setid() {
        if (confirm_Remove_Setid == null) {
            return "prompt";
        } else {
            return confirm_Remove_Setid;
        }
    }

    /**
     * Sets the value of the confirm_Remove_Setid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Remove_Setid(String value) {
        this.confirm_Remove_Setid = value;
    }

    /**
     * Gets the value of the confirm_Recreate_RepeatSet property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Recreate_RepeatSet() {
        if (confirm_Recreate_RepeatSet == null) {
            return "prompt";
        } else {
            return confirm_Recreate_RepeatSet;
        }
    }

    /**
     * Sets the value of the confirm_Recreate_RepeatSet property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Recreate_RepeatSet(String value) {
        this.confirm_Recreate_RepeatSet = value;
    }

}
